import React, { useMemo } from 'react';
import {
  geoEqualEarth,
  geoOrthographic,
  geoPath,
  geoGraticule,
} from 'd3';

const projection = geoEqualEarth();
const path = geoPath(projection);
const graticule = geoGraticule();

export const Marks = ({
  worldAtlas: { land, interiors },
  data,
  sizeValue,
  sizeScale,
}) => (
  <g className="marks">
    {useMemo(() => {
      return (
        <>
          <path
            className="sphere"
            d={path({ type: 'Sphere' })}
          />
          <path
            className="graticules"
            d={path(graticule())}
          />
          {land.features.map((feature) => (
            <path
              className="land"
              d={path(feature)}
            />
          ))}
          <path
            className="interiors"
            d={path(interiors)}
          />
        </>
      );
    }, [path, graticule, land, interiors])}
    {data.map((d) => {
      const [x, y] = projection([d.lng, d.lat]);

      return (
        <circle
          className="migrant"
          cx={x}
          cy={y}
          r={sizeScale(sizeValue(d))}
        />
      );
    })}
  </g>
);
