import React, { useState } from 'react';
import ReactDom from 'react-dom';
import { useWorldAtlas } from './useWorldAtlas';
import { useMigrantInfo } from './useMigrantInfo';
import { BubbleMap } from './BubbleMap/index.js';
import { DateHistogram } from '/DateHistogram/index.js';

const width = 960;
const height = 500;
const dateHistogramSize = 0.2;
const xValue = (d) => d['Reported Date'];

const App = () => {
  const worldAtlas = useWorldAtlas();
  const data = useMigrantInfo();
  const [brushExtent, setBrushExtent] = useState(
    null
  );

  if (!worldAtlas || !data) {
    return <pre>Loading...</pre>;
  }

  const filteredData = brushExtent
    ? data.filter((d) => {
        const date = xValue(d);
        return (
          date >= brushExtent[0] &&
          date < brushExtent[1]
        );
      })
    : data;

  return (
    <svg width={width} height={height}>
      <BubbleMap
        filteredData={filteredData}
        data={data}
        worldAtlas={worldAtlas}
      />
      <g
        transform={`translate(0,${
          height - dateHistogramSize * height
        })`}
      >
        <DateHistogram
          data={data}
          setBrushExtent={setBrushExtent}
          xValue={xValue}
          width={width}
          height={dateHistogramSize * height}
        />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById(
  'root'
);
ReactDOM.render(<App />, rootElement);
